pub enum MigrateV2Error {
UnknownSkipRules(String),
Walk(Error),
Io(Error),
MissingParent(PathBuf),
}Expand description
An error produced while validating or applying the migration codemod.
Variants
UnknownSkipRules(String)
One or more requested skip rules are not supported.
Walk(Error)
The source tree could not be walked.
Io(Error)
A source file could not be read or written.
MissingParent(PathBuf)
A file path does not have a parent directory for an atomic rewrite.